PCB Environment: NavPointRef Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
NavPointRef Class Reference

`#include <AStar.hpp>`

## Public Member Functions
| NavPointRef (NavPoint *nav, float v)
NavPoint * | getPoint () const
NavPoint * | operator-> () const
bool | operator< (const NavPointRef &that) const

## Detailed Description

As the A-star heuristic is not consistent, it can happen that we find a shorter path for a specific point and have to increase its priority in the open list. As std::priority_queue does not support changing the key, we insert nodes more than once. To avoid violating the heap property we have to score the key separately from NavPoint.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/AStar.hpp